/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/

package de.schmitzm.jfree.data;

import org.jfree.data.function.Function2D;
import org.jfree.data.xy.XYDataset;

/**
 * Dataset for a regression line. This class extends the
 * {@link XYDataset} with additional informations about the
 * regression line. 
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a>
 */
public interface RegressionDataset extends XYDataset {

  /**
   * Returns the R-value of the regression line, which is the
   * product-moment-correlation coefficient and gives information
   * about how strong the variables are related.
   */
  public double getR();
  
  /**
   * Returns a formatted representation of the R-value.
   * @see #getR()
   */
  public String getRFormatted();
  
  /**
   * Returns a quality representation of the R-value (e.g. weak,
   * medium, strong, ...).
   * @see #getR()
   */
  public String getRQuality();

  /**
   * Returns the 2 regression coefficients: [0] = the intercept; [1] = the slope.
   */
  public double[] getOLSRegressionCoefficients();

  /**
   * Returns the slope of the regression line.
   */
  public double getRegressionLineSlope();

  /**
   * Returns the intercept of the regression line.
   */
  public double getRegressionLineIntercept();

  /**
   * Returns the number of samples the regression calculation bases
   * on.
   */
  public int getSampleCount();

  /**
   * Returns the regression line for the dataset.
   */
  public Function2D getRegressionLine();

}
