package de.schmitzm.jfree.table;

import java.awt.Component;
import java.awt.event.ItemEvent;

import javax.swing.DefaultListCellRenderer;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.ListCellRenderer;

import de.schmitzm.jfree.JFreeChartUtil;
import de.schmitzm.lang.LangUtil;
import de.schmitzm.swing.SwingUtil;

/**
 * A {@link JComboBox} to select one {@link AggregationFunction}s. Can be
 * initialized to also support a <code>null</code>.<br/>
 * Note: Different from {@link JComboBox}, this does not fire events for DESELCTED events. 
 * 
 * @author SK
 */
public class AggregationFunctionJComboBox extends JComboBox {

	/**
	 * @param nullAlso
	 *            if <code>true</code>, <code>null</code> will be the first item
	 *            in the list.
	 */
	public AggregationFunctionJComboBox(boolean nullAlso) {
		super(nullAlso ? LangUtil.extendArray(
				new AggregationFunction[] { null }, AggregationFunction
						.values()) : AggregationFunction.values());
		setRenderer(listCellRenderer);
		SwingUtil.addMouseWheelForCombobox(this, false);
	}

	/**
	 * By default the <code>null</code> value is added.
	 */
	public AggregationFunctionJComboBox() {
		this(true);
	}
	
	/**
	 * A static {@link DefaultListCellRenderer} that will render instances of
	 * {@link AggregationFunction} with the title and description field as a
	 * tooltip.<br/>
	 * Any <code>null</code> value will also be rendered correctly.
	 */
	static ListCellRenderer listCellRenderer = new DefaultListCellRenderer() {

		@Override
		public Component getListCellRendererComponent(JList list, Object value,
				int index, boolean isSelected, boolean cellHasFocus) {

			Component proto = super.getListCellRendererComponent(list, value,
					index, isSelected, cellHasFocus);

			if (proto instanceof JLabel) {
				JLabel jLabel = (JLabel) proto;

				if (value instanceof AggregationFunction) {
					jLabel.setText(((AggregationFunction) value).getTitle());
					jLabel.setToolTipText(((AggregationFunction) value)
							.getDescription());
				} else if (value == null) {
					jLabel.setText(JFreeChartUtil
							.R("AggregationFunction.NONE.Title"));
					jLabel.setToolTipText(JFreeChartUtil
							.R("AggregationFunction.NONE.Desc"));
				}
			}

			return proto;
		}
	};
	
	/**
	 * The {@link JComboBox} does not fire events for DESELCTED event 
	 */
    @Override
	protected void fireItemStateChanged(ItemEvent e) {
    	if (e.getStateChange() == ItemEvent.DESELECTED) return;
    	super.fireItemStateChanged(e);
    }


}
